==> 0.0.2.tar.gz: example_app/lib/main.dart <==
import 'package:example_app/facebook/facebook_show_case.dart';
import 'package:example_app/google/google_show_case.dart';
import 'package:flutter/material.dart';
import 'package:th_studio_common_module/admod/mobile_admod.dart';

void main() {
  MobileAdModSdk.initialize();
  runApp(HomePage());
}

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        theme: ThemeData(
          primarySwatch: Colors.blue,
          visualDensity: VisualDensity.adaptivePlatformDensity,
        ),
        home: HomePageContent());
  }
}

class HomePageContent extends StatefulWidget {
  @override
  _HomePageContentState createState() => _HomePageContentState();
}

class _HomePageContentState extends State<HomePageContent> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Advertisements SDK'),
      ),
      body: ListView(
        children: [
          _createButton('Admod SDK', () => _onAdModClick()),
          _createButton('Facebook SDK', () => _onFacebookClick()),
        ],
      ),
    );
  }

  Widget _createButton(String title, VoidCallback onClick) {
    return Padding(
        padding: const EdgeInsets.only(top: 8.0, left: 8.0, right: 8.0),
        child: SizedBox(
            width: double.infinity,
            child: ElevatedButton(onPressed: onClick, child: Text(title))));
  }

  _onAdModClick() {
    Navigator.push(context, GoogleAdPage.buildPageRoute());
  }

  _onFacebookClick() {
    Navigator.push(context, FacebookAdPage.buildPageRoute());
  }
}

==> 0.0.6.tar.gz: example_app/lib/main.dart <==
import 'package:example_app/facebook/facebook_show_case.dart';
import 'package:example_app/google/google_show_case.dart';
import 'package:flutter/material.dart';
import 'package:th_studio_common_module/admod/mobile_sdk.dart';

void main() {
  MobileAdModSdk.initialize(testingId: '454d0cab-45aa-4a94-bde4-c12c1a62e07c');
  runApp(HomePage());
}

class HomePage extends StatefulWidget {
  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
        theme: ThemeData(
          primarySwatch: Colors.blue,
          visualDensity: VisualDensity.adaptivePlatformDensity,
        ),
        home: HomePageContent());
  }
}

class HomePageContent extends StatefulWidget {
  @override
  _HomePageContentState createState() => _HomePageContentState();
}

class _HomePageContentState extends State<HomePageContent> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('Advertisements SDK'),
      ),
      body: ListView(
        children: [
          _createButton('Admod SDK', () => _onAdModClick()),
          _createButton('Facebook SDK', () => _onFacebookClick()),
        ],
      ),
    );
  }

  Widget _createButton(String title, VoidCallback onClick) {
    return Padding(
        padding: const EdgeInsets.only(top: 8.0, left: 8.0, right: 8.0),
        child: SizedBox(
            width: double.infinity,
            child: ElevatedButton(onPressed: onClick, child: Text(title))));
  }

  _onAdModClick() {
    Navigator.push(context, GoogleAdPage.buildPageRoute());
  }

  _onFacebookClick() {
    Navigator.push(context, FacebookAdPage.buildPageRoute());
  }
}
